@@ -5,7 +5,7 @@
  *                                                                         *
  ***********************IMPORTANT NMAP LICENSE TERMS************************
  *                                                                         *
- * The Nmap Security Scanner is (C) 1996-2006 Insecure.Com LLC. Nmap is    *
+ * The Nmap Security Scanner is (C) 1996-2008 Insecure.Com LLC. Nmap is    *
  * also a registered trademark of Insecure.Com LLC.  This program is free  *
  * software; you may redistribute and/or modify it under the terms of the  *
  * GNU General Public License as published by the Free Software            *
@@ -38,7 +38,7 @@
  * These restrictions only apply when you actually redistribute Nmap.  For *
  * example, nothing stops you from writing and selling a proprietary       *
  * front-end to Nmap.  Just distribute it by itself, and point people to   *
- * http://insecure.org/nmap/ to download Nmap.                             *
+ * http://nmap.org to download Nmap.                                       *
  *                                                                         *
  * We don't consider these to be added restrictions on top of the GPL, but *
  * just a clarification of how we interpret "derived works" as it applies  *
@@ -77,7 +77,7 @@
  * Source code also allows you to port Nmap to new platforms, fix bugs,    *
  * and add new features.  You are highly encouraged to send your changes   *
  * to fyodor@insecure.org for possible incorporation into the main         *
- * distribution.  By sending these changes to Fyodor or one the            *
+ * distribution.  By sending these changes to Fyodor or one of the         *
  * Insecure.Org development mailing lists, it is assumed that you are      *
  * offering Fyodor and Insecure.Com LLC the unlimited, non-exclusive right *
  * to reuse, modify, and relicense the code.  Nmap will always be          *
@@ -97,14 +97,11 @@
  *                                                                         *
  ***************************************************************************/
 
-/* $Id: main.cc 4123 2006-11-03 05:36:41Z fyodor $ */
+/* $Id: main.cc 6858 2008-02-28 18:52:06Z fyodor $ */
 
 #include "nmap.h"
-#include "osscan.h"
-#include "scan_engine.h"
-#include "idle_scan.h"
-#include "timing.h"
 #include "NmapOps.h"
+#include "utils.h"
 
 #ifdef MTRACE
 #include "mcheck.h"
@@ -140,14 +137,9 @@ extern NmapOps o;  /* option structure */
 int main(int argc, char *argv[]) {
   /* The "real" main is nmap_main().  This function hijacks control at the
      beginning to do the following:
-     1) Check if Nmap called under name listed in INTERACTIVE_NAMES or with
-     interactive.
+     1) Check if Nmap was called with --interactive.
      2) Start interactive mode or just call nmap_main
   */
-  char *interactive_names[] = INTERACTIVE_NAMES;
-  int numinames = sizeof(interactive_names) / sizeof(char *);
-  int nameidx;
-  char *nmapcalledas;
   char command[2048];
   int myargc, fakeargc;
   char **myargv = NULL, **fakeargv = NULL;
@@ -200,15 +192,8 @@ int main(int argc, char *argv[]) {
 #endif
 #endif
 
-  /* First we figure out whether the name nmap is called as qualifies it 
-     for interactive mode treatment */
-  nmapcalledas = strrchr(argv[0], '/');
-  if (!nmapcalledas) {
-    nmapcalledas = argv[0];
-  } else nmapcalledas++;
-
   if ((cptr = getenv("NMAP_ARGS"))) {
-    if (snprintf(command, sizeof(command), "nmap %s", cptr) >= (int) sizeof(command)) {
+    if (Snprintf(command, sizeof(command), "nmap %s", cptr) >= (int) sizeof(command)) {
         error("Warning: NMAP_ARGS variable is too long, truncated");
     }
     /* copy rest of command-line arguments */
@@ -225,14 +210,6 @@ int main(int argc, char *argv[]) {
     return ret;
   }
 
-  for(nameidx = 0; nameidx < numinames; nameidx++) {
-    if (strcasecmp(nmapcalledas, interactive_names[nameidx]) == 0) {
-      printf("Entering Interactive Mode because argv[0] == %s\n", nmapcalledas);
-      interactivemode = 1;
-      break;
-    }
-  }
-
   if (interactivemode == 0 &&
       argc == 2 && strcmp("--interactive", argv[1]) == 0) {
     interactivemode = 1;
@@ -249,7 +226,7 @@ int main(int argc, char *argv[]) {
     }
     return nmap_main(argc, argv);
   }
-  /*  printf("\nStarting nmap V. %s by fyodor@insecure.org ( www.insecure.org/nmap/ )\n", VERSION);*/
+
   printf("\nStarting %s V. %s ( %s )\n", NMAP_NAME, NMAP_VERSION, NMAP_URL);
 
   printf("Welcome to Interactive Mode -- press h <enter> for help\n");
@@ -336,18 +313,23 @@ int main(int argc, char *argv[]) {
 	    if ((pptr = getenv("PATH"))) {
 	      Strncpy(path, pptr, sizeof(path));
 	      pptr = path;
+	      /* Get the name Nmap was called as. */
+	      char *nmapcalledas = path_get_basename(argv[0]);
+	      if (nmapcalledas == NULL)
+		pfatal("Could not get nmap executable basename");
 	      while(pptr && *pptr) {
 		endptr = strchr(pptr, ':');
 		if (endptr) { 
 		  *endptr = '\0';
 		}
-		snprintf(nmappath, sizeof(nmappath), "%s/%s", pptr, nmapcalledas);
+		Snprintf(nmappath, sizeof(nmappath), "%s/%s", pptr, nmapcalledas);
 		if (stat(nmappath, &st) != -1)
 		  break;
 		nmappath[0] = '\0';
 		if (endptr) pptr = endptr + 1;
 		else pptr = NULL;
 	      }
+	      free(nmapcalledas);
 	    }
 	  }
 	}
@@ -373,7 +355,7 @@ int main(int argc, char *argv[]) {
 	  }
 	} else {
 	  fakeargc = 1;
-	  fakeargv = (char **) malloc(sizeof(char *) * 2);
+	  fakeargv = (char **) safe_malloc(sizeof(char *) * 2);
 	  fakeargv[0] = nmappath;
 	  fakeargv[1] = NULL;
 	}
