@@ -20,6 +20,7 @@ extern "C" {
 #include "NmapOps.h"
 #include "timing.h"
 #include "Target.h"
+#include "nmap_tty.h"
 
 extern NmapOps o;
 
@@ -225,7 +226,7 @@ finishup:
 	current_hosts.clear();
 	torun_scripts.clear();
 	if(status != SCRIPT_ENGINE_SUCCESS) {
-		error("%s: Aborting script scan.\n", SCRIPT_ENGINE);
+		error("%s: Aborting script scan.", SCRIPT_ENGINE);
 		return SCRIPT_ENGINE_ERROR;
 	} else {
 		return SCRIPT_ENGINE_SUCCESS;
@@ -242,6 +243,9 @@ int process_mainloop(lua_State* l) {
 	double total = (double) unfinished;
 	double done = 0;
 
+	std::list<struct thread_record>::iterator iter;
+	struct timeval now;
+
 	// while there are scripts in running or waiting state, we loop.
 	// we rely on nsock_loop to protect us from busy loops when 
 	// all scripts are waiting.
@@ -254,6 +258,15 @@ int process_mainloop(lua_State* l) {
 
 		unfinished = running_scripts.size() + waiting_scripts.size();
 
+		if (keyWasPressed()) {
+			done = 1.0 - (((double) unfinished) / total);
+			if (o.verbose > 1 || o.debugging) {
+				log_write(LOG_STDOUT, "Active NSE scripts: %d\n", unfinished);
+				log_flush(LOG_STDOUT);
+			}
+			progress.printStats(done, NULL);
+		}
+
 		SCRIPT_ENGINE_VERBOSE(
 			if(progress.mayBePrinted(NULL)) { 
 				done = 1.0 - (((double) unfinished) / total);
@@ -263,52 +276,64 @@ int process_mainloop(lua_State* l) {
 					progress.printStatsIfNeccessary(done, NULL);
 			})
 
+		gettimeofday(&now, NULL);
 
-		if(running_scripts.begin() == running_scripts.end())
-			continue;
-
-		current = *(running_scripts.begin());
-		state = lua_resume(current.thread, current.resume_arguments);
-
-		if(state == LUA_YIELD) {
-			// this script has performed a network io operation
-			// we put it in the waiting
-			// when the network io operation has completed,
-			// a callback from the nsock library will put the
-			// script back into the running state
-			
-			waiting_scripts.push_back(current);
-			running_scripts.pop_front();
-		} else if( state == 0) {
-			// this script has finished
-			// we first check if it produced output
-			// then we release the thread and remove it from the
-			// running_scripts list
-
-			if(lua_isstring (current.thread, -1)) {
-				SCRIPT_ENGINE_TRY(process_getScriptId(current.thread, &ssr));
-				ssr.output = nse_printable
-					(lua_tostring(current.thread, -1), lua_objlen(current.thread, -1));
-				if(current.rr->type == 0) {
-					current.rr->host->scriptResults.push_back(ssr);
-				} else if(current.rr->type == 1) {
-					current.rr->port->scriptResults.push_back(ssr);
-					current.rr->host->ports.numscriptresults++;
-				}
-				lua_pop(current.thread, 2);
+		for(iter = waiting_scripts.begin(); iter != waiting_scripts.end(); iter++)
+			if (iter->rr->host->timedOut(&now)) {
+				running_scripts.push_front((*iter));
+				waiting_scripts.erase(iter);
+				iter = waiting_scripts.begin();
 			}
 
-			SCRIPT_ENGINE_TRY(process_finalize(l, current.registry_idx));
-			SCRIPT_ENGINE_TRY(lua_gc(l, LUA_GCCOLLECT, 0));
-		} else {
-			// this script returned because of an error
-			// print the failing reason if the verbose level is high enough	
-			SCRIPT_ENGINE_DEBUGGING(
-				const char* errmsg = lua_tostring(current.thread, -1);
-				log_write(LOG_STDOUT, "%s: %s\n", SCRIPT_ENGINE, errmsg);
-			)
-			SCRIPT_ENGINE_TRY(process_finalize(l, current.registry_idx));
-		}
+
+		while(running_scripts.begin() != running_scripts.end()){
+			current = *(running_scripts.begin());
+	
+			if (current.rr->host->timedOut(&now))
+				state = LUA_ERRRUN;
+			else
+				state = lua_resume(current.thread, current.resume_arguments);
+	
+			if(state == LUA_YIELD) {
+				// this script has performed a network io operation
+				// we put it in the waiting
+				// when the network io operation has completed,
+				// a callback from the nsock library will put the
+				// script back into the running state
+				
+				waiting_scripts.push_back(current);
+				running_scripts.pop_front();
+			} else if( state == 0) {
+				// this script has finished
+				// we first check if it produced output
+				// then we release the thread and remove it from the
+				// running_scripts list
+	
+				if(lua_isstring (current.thread, -1)) {
+					SCRIPT_ENGINE_TRY(process_getScriptId(current.thread, &ssr));
+					ssr.output = nse_printable
+						(lua_tostring(current.thread, -1), lua_objlen(current.thread, -1));
+					if(current.rr->type == 0) {
+						current.rr->host->scriptResults.push_back(ssr);
+					} else if(current.rr->type == 1) {
+						current.rr->port->scriptResults.push_back(ssr);
+						current.rr->host->ports.numscriptresults++;
+					}
+					lua_pop(current.thread, 2);
+				}
+	
+				SCRIPT_ENGINE_TRY(process_finalize(l, current.registry_idx));
+				SCRIPT_ENGINE_TRY(lua_gc(l, LUA_GCCOLLECT, 0));
+			} else {
+				// this script returned because of an error
+				// print the failing reason if the verbose level is high enough	
+				SCRIPT_ENGINE_DEBUGGING(
+					const char* errmsg = lua_tostring(current.thread, -1);
+					log_write(LOG_STDOUT, "%s: %s\n", SCRIPT_ENGINE, errmsg);
+				)
+				SCRIPT_ENGINE_TRY(process_finalize(l, current.registry_idx));
+			}
+		} // while
 	}
 
 	progress.endTask(NULL, NULL);
@@ -316,10 +341,30 @@ int process_mainloop(lua_State* l) {
 	return SCRIPT_ENGINE_SUCCESS;
 }
 
+// If the target still has scripts in either running_scripts
+// or waiting_scripts then it is still running
+
+int has_target_finished(Target *target) {
+	std::list<struct thread_record>::iterator iter;
+
+	for (iter = waiting_scripts.begin(); iter != waiting_scripts.end(); iter++)
+		if (target == iter->rr->host) return 0;
+
+	for (iter = running_scripts.begin(); iter != running_scripts.end(); iter++)
+		if (target == iter->rr->host) return 0;
+
+	return 1;
+}
+
 int process_finalize(lua_State* l, unsigned int registry_idx) {
 	luaL_unref(l, LUA_REGISTRYINDEX, registry_idx);
+	struct thread_record thr = running_scripts.front();
+
 	running_scripts.pop_front();
 
+	if (has_target_finished(thr.rr->host))
+		thr.rr->host->stopTimeOutClock(NULL);
+
 	return SCRIPT_ENGINE_SUCCESS;
 }
 
@@ -330,14 +375,20 @@ int process_waiting2running(lua_State* l, int resume_arguments) {
 	for(	iter = waiting_scripts.begin(); 
 		(*iter).thread != l;
 		iter++) {
+
 		// It is very unlikely that a thread which
 		// is not in the waiting queue tries to
 		// continue
 		// it does happen when they try to do socket i/o
 		// inside a pcall
+
+		// This also happens when we timeout a script
+		// In this case, the script is still in the waiting
+		// queue and we will have manually removed it from
+		// the waiting queue so we just return.
+
 		if(iter == waiting_scripts.end())
-			fatal("%s: In: %s:%i This should never happen.", 
-					SCRIPT_ENGINE, __FILE__, __LINE__);
+			return SCRIPT_ENGINE_SUCCESS;
 	}
 
 	(*iter).resume_arguments = resume_arguments;
@@ -364,7 +415,7 @@ int process_getScriptId(lua_State* l, struct script_scan_result *ssr) {
 	} else if(lua_isstring(l, -1)) {
 		ssr->id = strdup(lua_tostring (l, -1));
 	} else {
-		error("%s: The script has no 'id' entry, the 'filename' entry was changed to: \n",
+		error("%s: The script has no 'id' entry, the 'filename' entry was changed to:",
 			SCRIPT_ENGINE);
 		l_dumpValue(l, -1);
 		return SCRIPT_ENGINE_ERROR;
@@ -390,6 +441,9 @@ int process_preparehost(lua_State* l, Target* target, std::list<struct thread_re
 	std::vector<run_record>::iterator iter;
 	struct run_record rr;
 
+	if (!target->timeOutClockRunning())
+		target->startTimeOutClock(NULL);
+
 	/* find the matching hostrules
 	 * */
 	lua_getglobal(l, HOSTTESTS);
