@@ -221,6 +221,23 @@ static int l_nsock_connect_queued(lua_State* l) {
      script might open a few sockets at once and we don't want it to
      deadlock when it tries to open the 2nd one. */
 	const int max_descriptors_allowed = MAX(o.max_parallelism, 10);
+	
+	
+	l_nsock_udata* udata = (l_nsock_udata*) auxiliar_checkclass(l, "nsock", 1);
+	
+	if(udata->nsiod!=NULL){
+		/*should a script try to connect a socket, which is already connected
+		 * we close the old connection, since it would have no access to it 
+		 * anyways
+		 */
+		if(o.scriptTrace()){
+			log_write(LOG_STDOUT,"%s: Trying to connect already connected socket - closing!\n",SCRIPT_ENGINE);
+		}
+		l_nsock_close(l);
+		lua_pop(l,1);
+	}
+	
+	
 	if(nsock_descriptors_used >= max_descriptors_allowed){
 		/* wait for free descriptor */
 		nsock_connect_queue.push_back(l);
@@ -269,7 +286,7 @@ static int l_nsock_connect(lua_State* l) {
 	int error_id;
 	
 	l_nsock_clear_buf(l, udata);
-
+	
 	error_id = getaddrinfo(addr, NULL, NULL, &dest);
 	if (error_id) {
 		error = gai_strerror(error_id);
@@ -449,7 +466,8 @@ void l_nsock_trace(nsock_iod nsiod, char* message, int direction) {
 	if(!nsi_is_pcap(nsiod)){
 		status =  nsi_getlastcommunicationinfo(nsiod, &protocol, &af,
 			&local, &remote, sizeof(sockaddr)); 
-		log_write(LOG_STDOUT, "SCRIPT ENGINE: %s %s:%d %s %s:%d | %s\n", 
+		log_write(LOG_STDOUT, "%s: %s %s:%d %s %s:%d | %s\n", 
+			SCRIPT_ENGINE,
 			(protocol == IPPROTO_TCP)? "TCP" : "UDP",
 			inet_ntop_both(af, &local, ipstring_local), 
 			inet_port_both(af, &local), 
@@ -461,7 +479,8 @@ void l_nsock_trace(nsock_iod nsiod, char* message, int direction) {
 		free(ipstring_local);
 		free(ipstring_remote);
 	}else{ // is pcap device
-		log_write(LOG_STDOUT, "SCRIPT ENGINE: %s | %s\n", 
+		log_write(LOG_STDOUT, "%s: %s | %s\n", 
+			SCRIPT_ENGINE,
 			(direction == TO)? ">" : "<", 
 			message); 
 	}
